Class: Aws::ConnectContactLens::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectContactLens::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcontactlens/client.rb,
sig/client.rbs
Overview
An API client for ConnectContactLens. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectContactLens::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ListRealtimeContactAnalysisSegmentsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#list_realtime_contact_analysis_segments(params = {}) ⇒ Types::ListRealtimeContactAnalysisSegmentsResponse
Provides a list of analysis segments for a real-time analysis session for voice.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectcontactlens/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
588 589 590 |
# File 'lib/aws-sdk-connectcontactlens/client.rb', line 588 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
591 592 593 |
# File 'lib/aws-sdk-connectcontactlens/client.rb', line 591 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-connectcontactlens/client.rb', line 561 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectContactLens') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcontactlens' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#list_realtime_contact_analysis_segments(params = {}) ⇒ Types::ListRealtimeContactAnalysisSegmentsResponse
Provides a list of analysis segments for a real-time analysis session for voice.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
87 |
# File 'sig/client.rbs', line 87
def list_realtime_contact_analysis_segments: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
581 582 583 |
# File 'lib/aws-sdk-connectcontactlens/client.rb', line 581 def waiter_names [] end |