Class: Aws::ConnectContactLens::Types::ExtractedInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcontactlens/types.rb

Overview

Segment containing information extracted from the conversation. Each segment represents the results for a single extraction definition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#extracted_valuesArray<Types::ExtractedInformationValue>

The list of values extracted from the conversation for this extraction definition. This field is empty when a FailureCode is present.



126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 126

class ExtractedInformation < Struct.new(
  :extraction_definition_id,
  :extraction_definition_name,
  :extraction_definition_display_label,
  :extracted_values,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#extraction_definition_display_labelString

The display label of the extraction definition that produced this result.

Returns:

  • (String)


126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 126

class ExtractedInformation < Struct.new(
  :extraction_definition_id,
  :extraction_definition_name,
  :extraction_definition_display_label,
  :extracted_values,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#extraction_definition_idString

The identifier of the extraction definition that produced this result.

Returns:

  • (String)


126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 126

class ExtractedInformation < Struct.new(
  :extraction_definition_id,
  :extraction_definition_name,
  :extraction_definition_display_label,
  :extracted_values,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#extraction_definition_nameString

The name of the extraction definition that produced this result.

Returns:

  • (String)


126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 126

class ExtractedInformation < Struct.new(
  :extraction_definition_id,
  :extraction_definition_name,
  :extraction_definition_display_label,
  :extracted_values,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

If the information failed to be extracted, one of the following failure codes occurs:

  • QUOTA_EXCEEDED: The number of concurrent analytics jobs reached your service quota.

  • INSUFFICIENT_CONVERSATION_CONTENT: Information extraction requires a conversation with at least one turn from each participant.

  • FAILED_SAFETY_GUIDELINES: The extracted information cannot be provided because it failed to meet system safety guidelines.

  • INTERNAL_ERROR: Internal system error.

  • MAX_PACKAGE_FEATURE_ONLY: Information extraction is only available in Amazon Connect Customer instances.

Returns:

  • (String)


126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 126

class ExtractedInformation < Struct.new(
  :extraction_definition_id,
  :extraction_definition_name,
  :extraction_definition_display_label,
  :extracted_values,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end