Class: Aws::ConnectContactLens::Types::ExtractedInformationValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcontactlens/types.rb

Overview

An individual value extracted from the conversation, including its content and the locations where it was found.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The text content of the extracted value.

Returns:

  • (String)


150
151
152
153
154
155
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 150

class ExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end

#points_of_interestArray<Types::PointOfInterest>

The sections in the conversation that indicate where the extracted value was found.

Returns:



150
151
152
153
154
155
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 150

class ExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end