Class: Aws::ConnectContactLens::Types::ListRealtimeContactAnalysisSegmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectContactLens::Types::ListRealtimeContactAnalysisSegmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcontactlens/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact.
218 219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 218 class ListRealtimeContactAnalysisSegmentsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
218 219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 218 class ListRealtimeContactAnalysisSegmentsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
218 219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 218 class ListRealtimeContactAnalysisSegmentsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
218 219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 218 class ListRealtimeContactAnalysisSegmentsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |