Class: Aws::ConnectContactLens::Types::ListRealtimeContactAnalysisSegmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectContactLens::Types::ListRealtimeContactAnalysisSegmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcontactlens/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#segments ⇒ Array<Types::RealtimeContactAnalysisSegment>
An analyzed transcript or category.
Instance Attribute Details
#next_token ⇒ String
If there are additional results, this is the token for the next set
of results. If response includes nextToken there are two possible
scenarios:
-
There are more segments so another call is required to get them.
-
There are no more segments at this time, but more may be available later (real-time analysis is in progress) so the client should call the operation again to get new segments.
If response does not include nextToken, the analysis is completed
(successfully or failed) and there are no more segments to retrieve.
248 249 250 251 252 253 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 248 class ListRealtimeContactAnalysisSegmentsResponse < Struct.new( :segments, :next_token) SENSITIVE = [] include Aws::Structure end |
#segments ⇒ Array<Types::RealtimeContactAnalysisSegment>
An analyzed transcript or category.
248 249 250 251 252 253 |
# File 'lib/aws-sdk-connectcontactlens/types.rb', line 248 class ListRealtimeContactAnalysisSegmentsResponse < Struct.new( :segments, :next_token) SENSITIVE = [] include Aws::Structure end |